AbortHandle

Struct AbortHandle 

pub struct AbortHandle { /* private fields */ }
A handle used to abort a Command remotely before it is complete

Implementations

Source

impl AbortHandle

pub fn abort(&self)

Abort the associated Command and all its tasks.

The tasks will be stopped (not polled any more) at the next .await point. If you use this, make sure the tasks the Command is running are all cancellation safe, as they can be stopped at any of the await points or even before they are first polled